@@ -8,7 +8,7 @@ int hitandrun_hit(Matrix *constr, double *rhs, double *x, double epsilon) {
 	double a[constr->nRow];
 	F77_CALL(dgemv)(&trans, &(constr->nRow), &(constr->nCol),
 		&one, constr->data, &(constr->nRow), x, &inc1,
-		&zero, a, &inc1); // a := 1Ax + 0a
+		&zero, a, &inc1 FCONE); // a := 1Ax + 0a
 
 	for (int i = 0; i < constr->nRow; ++i) {
 		if (a[i] - rhs[i] > epsilon) {
